==> ejc-purchasingmanagement-impl-3.0.0-20220714.104004-159-sources.jar: com/ejianc/business/purchasingmanagement/controller/MaterialplanController.java <==
package com.ejianc.business.purchasingmanagement.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.purchasingmanagement.bean.*;
import com.ejianc.business.purchasingmanagement.vo.MaterialPlanStatisticsVO;
import com.ejianc.business.purchasingmanagement.vo.MaterialplanVO;
import com.ejianc.business.purchasingmanagement.vo.PurchasedetilVO;
import com.ejianc.business.purchasingmanagement.service.*;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

/**
 * 定料计划
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("materialplan")
public class MaterialplanController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IMaterialplanService service;
    @Autowired
    private IPurchasedetilService purchasedetilService;
    @Autowired
    private IPurchasetransportationService purchasetransportationService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<MaterialplanVO> saveOrUpdate(@RequestBody MaterialplanVO saveOrUpdateVO) {

        return  service.saveChange(saveOrUpdateVO);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<MaterialplanVO> queryDetail(Long id) {
    	MaterialplanEntity entity = service.selectById(id);
    	MaterialplanVO vo = BeanMapper.map(entity, MaterialplanVO.class);
    	//收货列表
        QueryWrapper<PurchasedetilEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("materialplan_id",id);
        queryWrapper.eq("dr",0);
        List<PurchasedetilEntity>  purchasedetilEntities  = purchasedetilService.list(queryWrapper);
        vo.setPurchasedetilList(BeanMapper.mapList(purchasedetilEntities, PurchasedetilVO.class));
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<MaterialplanVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (MaterialplanVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(MaterialplanVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<MaterialplanVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("supplierinfoName");
        fuzzyFields.add("billCode");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<MaterialplanEntity> page = service.queryPage(param,false);
        IPage<MaterialplanVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), MaterialplanVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<MaterialplanEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Materialplan-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refMaterialplanData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<MaterialplanVO>> refMaterialplanData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<MaterialplanEntity> page = service.queryPage(param,false);
        IPage<MaterialplanVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), MaterialplanVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    /**
     * @Description 关闭定料计划
     * @param id
     */
    @RequestMapping(value = "/updateIsColse", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<MaterialplanVO> updateIsColse(Long id) {
        MaterialplanEntity entity = service.selectById(id);
        entity.setIsColse(0);
        service.updateById(entity);
        QueryWrapper<PurchasetransportationEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("materialplan_id",id);
        List<PurchasetransportationEntity> list = purchasetransportationService.list(queryWrapper);
        for (PurchasetransportationEntity entity1 : list){
            entity1.setIsColse(0);
            purchasetransportationService.updateById(entity1);
        }
        MaterialplanVO vo = BeanMapper.map(entity, MaterialplanVO.class);
        return CommonResponse.success("关闭成功",vo);
    }
    /**
     * @Description 查询定料计划执行统计
     * @param orgId
     */
    @RequestMapping(value = "/queryPlanPercent", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<MaterialPlanStatisticsVO>> queryPlanPercent(Long orgId) {
        QueryWrapper queryWrapper=new QueryWrapper();
        queryWrapper.eq("org_id",orgId);
        queryWrapper.eq("is_colse",1);
        List<MaterialplanEntity> list = service.list(queryWrapper);
        List<MaterialPlanStatisticsVO> VOS = BeanMapper.mapList(list, MaterialPlanStatisticsVO.class);
        for (MaterialPlanStatisticsVO vo : VOS) {
            if (vo.getQuantityReceived()==null){
                vo.setPercent("0%");
                vo.setQuantityReceived(new BigDecimal("0"));
            }else {
                vo.setPercent(vo.getQuantityReceived().divide(vo.getQuantity(),2).toPlainString()+"%");
            }
        }
        return CommonResponse.success("查询定料计划成功",VOS);
    }
}

==> ejc-purchasingmanagement-impl-3.0.0-20220903.162409-208-sources.jar: com/ejianc/business/purchasingmanagement/controller/MaterialplanController.java <==
package com.ejianc.business.purchasingmanagement.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.purchasingmanagement.bean.*;
import com.ejianc.business.purchasingmanagement.service.*;
import com.ejianc.business.purchasingmanagement.utils.DateUtil;
import com.ejianc.business.purchasingmanagement.vo.*;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

/**
 * 定料计划
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("materialplan")
public class MaterialplanController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IMaterialplanService service;
    @Autowired
    private IPurchasedetilService purchasedetilService;//采购信息明细表
    @Autowired
    private IPurchasetransportationService purchasetransportationService;//采购运输信息

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<MaterialplanVO> saveOrUpdate(@RequestBody MaterialplanVO saveOrUpdateVO) {

        return  service.saveChange(saveOrUpdateVO);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<MaterialplanVO> queryDetail(Long id) throws ParseException {
    	MaterialplanEntity entity = service.selectById(id);
    	MaterialplanVO vo = BeanMapper.map(entity, MaterialplanVO.class);
    	//收货列表
        QueryWrapper<PurchasedetilEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("materialplan_id",id);
        queryWrapper.eq("dr",0);
        List<PurchasedetilEntity>  purchasedetilEntities  = purchasedetilService.list(queryWrapper);
        vo.setPurchasedetilList(BeanMapper.mapList(purchasedetilEntities, PurchasedetilVO.class));
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<MaterialplanVO> vos) {
        //获取传入的数据，进行不为空的判断
        if(ListUtil.isNotEmpty(vos)){
            //不为空，传入for循环
            for (MaterialplanVO vo : vos) {
                //根据id查询数据
                MaterialplanEntity entity = service.selectById(vo.getId());
                //判断已收获数量不为空或不为0，是则抛异常，结束程序
                if (null != entity.getQuantityReceived()){
                    throw new BusinessException("删除数据还有未完成接收数量，删除失败");
                }
                //TODO  如果为空或者为零时 同步删除采购运输信息表（一个订料计划对应一个采购运算信息）
                //作条件筛选器
                QueryWrapper<PurchasetransportationEntity>  purchasetransportationEntityQueryWrapper = new QueryWrapper<>();//新new筛选构造器（类比SQL的where操作）
                purchasetransportationEntityQueryWrapper.eq("materialplan_id",entity.getId());//（条件，类比SQLwhere后面的条件）
                //查询数据
                PurchasetransportationEntity purchasetransportationEntity = purchasetransportationService.getOne(purchasetransportationEntityQueryWrapper);
                //删除查询到的采购运输单数据
                purchasetransportationService.removeById(purchasetransportationEntity.getId());

                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        //执行删除
        service.removeByIds(vos.stream().map(MaterialplanVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<MaterialplanVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("supplierinfoName");
        fuzzyFields.add("billCode");
        fuzzyFields.add("materialName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));


        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<MaterialplanEntity> page = service.queryPage(param,false);
        IPage<MaterialplanVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), MaterialplanVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("start_date");
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<MaterialplanEntity> list = service.queryList(param);
        List<MaterialplanVO> vo=BeanMapper.mapList(list,MaterialplanVO.class);
        for(MaterialplanVO materialplanVO:vo) {
            SimpleDateFormat sdf=new SimpleDateFormat("yyyy-MM-dd");
            SimpleDateFormat sdf1=new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            materialplanVO.setStartDates(sdf.format(materialplanVO.getStarDate()));
            materialplanVO.setEndDates(sdf1.format(materialplanVO.getEndDate()));
            if(materialplanVO.getIsColse()==1){
                materialplanVO.setIsColses("未关闭");
            }else{
                materialplanVO.setIsColses("已关闭");
            }
        }
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", vo);
        ExcelExport.getInstance().export("Materialplan-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */

    @RequestMapping(value = "/refMaterialplanData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<MaterialplanVO>> refMaterialplanData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<MaterialplanEntity> page = service.queryPage(param,false);
        IPage<MaterialplanVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), MaterialplanVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    /**
     * @Description 关闭定料计划
     * @param id
     */
    @RequestMapping(value = "/updateIsColse", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<MaterialplanVO> updateIsColse(Long id) {
        MaterialplanEntity entity = service.selectById(id);
        entity.setIsColse(0);
        service.updateById(entity);
        QueryWrapper<PurchasetransportationEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("materialplan_id",id);
        List<PurchasetransportationEntity> list = purchasetransportationService.list(queryWrapper);
        for (PurchasetransportationEntity entity1 : list){
            entity1.setIsColse(0);
            purchasetransportationService.updateById(entity1);
        }
        MaterialplanVO vo = BeanMapper.map(entity, MaterialplanVO.class);
        return CommonResponse.success("关闭成功",vo);
    }
    /**
     * @Description 查询定料计划执行统计
     * @param orgId
     */
    @RequestMapping(value = "/queryPlanPercent", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<MaterialPlanStatisticsVO>> queryPlanPercent(Long orgId) {
        QueryWrapper queryWrapper=new QueryWrapper();
        queryWrapper.eq("org_id",orgId);
        queryWrapper.eq("is_colse",1);
        List<MaterialplanEntity> list = service.list(queryWrapper);
        List<MaterialPlanStatisticsVO> VOS = BeanMapper.mapList(list, MaterialPlanStatisticsVO.class);
        for (MaterialPlanStatisticsVO vo : VOS) {
            if (vo.getQuantityReceived()==null){
                vo.setPercent("0%");
                vo.setQuantityReceived(new BigDecimal("0"));
            }else {
                vo.setPercent(vo.getQuantityReceived().divide(vo.getQuantity(),2).toPlainString()+"%");
            }
        }
        return CommonResponse.success("查询定料计划成功",VOS);
    }
    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/orderingSchedulesTime", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> orderingSchedulesTime() {

        service.orderingSchedulesTime();

        return CommonResponse.success("保存或修改单据成功！");
    }

    @RequestMapping(value = "/updateStage", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<MaterialplanVO> updateStage(@RequestBody MaterialplanVO saveOrUpdateVO) {
        MaterialplanEntity entity = BeanMapper.map(saveOrUpdateVO, MaterialplanEntity.class);
        entity.setStage(0);
        service.updateById(entity);
        MaterialplanVO vo = BeanMapper.map(entity, MaterialplanVO.class);
        return CommonResponse.success("保存或修改单据成功！",vo);
    }


}
